#
# spec file for package dom4j
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2000-2007, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global base_name dom4j
%global flavor %{nil}
%if "%{flavor}" == "bootstrap"
%bcond_without bootstrap
%else
%bcond_with bootstrap
%endif
Version:        2.1.4
Release:        4.3
Summary:        Open Source XML framework for Java
License:        Plexus
URL:            https://dom4j.github.io/
Source0:        %{base_name}-%{version}.tar.xz
Source1:        https://repo1.maven.org/maven2/org/%{base_name}/%{base_name}/%{version}/%{base_name}-%{version}.pom
Source2:        %{base_name}-build.xml
Patch0:         0001-no-jaxen-dom4.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  glassfish-jaxb-api
BuildRequires:  javapackages-local >= 6
Obsoletes:      %{base_name}-manual < %{version}
BuildArch:      noarch
%if %{with bootstrap}
Name:           %{base_name}-bootstrap
%else
Name:           %{base_name}
%endif
%if %{without bootstrap}
BuildRequires:  fdupes
BuildRequires:  jaxen
Conflicts:      %{base_name}-bootstrap
Obsoletes:      %{base_name}-bootstrap
%else
BuildRequires:  jaxen-bootstrap
Conflicts:      %{base_name}
%endif

%description
dom4j is an Open Source XML framework for Java. dom4j allows you to read,
write, navigate, create and modify XML documents. dom4j integrates with
DOM and SAX and is seamlessly integrated with full XPath support.

%if %{without bootstrap}
%package demo
Summary:        Open Source XML framework for Java - demo
Group:          Development/Libraries/Java
Requires:       %{base_name} = %{version}

%description demo
dom4j is an Open Source XML framework for Java. dom4j allows you to read,
write, navigate, create and modify XML documents. dom4j integrates with
DOM and SAX and is seamlessly integrated with full XPath support.

%package javadoc
Summary:        Javadoc for %{base_name}

%description javadoc
Javadoc for %{base_name}.
%endif

%prep
%setup -q -n %{base_name}-%{version}
%if %{with bootstrap}
%patch -P 0 -p1
%endif

cp %{SOURCE1} pom.xml
cp %{SOURCE2} build.xml

# Remove xpp2 support
rm -r src/main/java/org/dom4j/xpp
rm src/main/java/org/dom4j/io/XPPReader.java

# Remove datatype code which depends on msv
rm -r src/main/java/org/dom4j/datatype
%pom_remove_dep net.java.dev.msv:xsdlib

# Remove xpp3 support
rm src/main/java/org/dom4j/io/XPP3Reader.java
%pom_remove_dep xpp3:xpp3
%pom_remove_dep pull-parser:pull-parser
%pom_remove_dep javax.xml.stream:stax-api

%build
mkdir -p lib
build-jar-repository -s lib jaxen glassfish-jaxb-api
%{ant} jar javadoc

%install

# jar
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 target/%{base_name}-%{version}.jar %{buildroot}%{_javadir}/%{base_name}.jar

%if %{without bootstrap}
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{base_name}.pom
%add_maven_depmap %{base_name}.pom %{base_name}.jar -a %{base_name}:%{base_name}

# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{base_name}
cp -r target/site/apidocs %{buildroot}%{_javadocdir}/%{base_name}
%fdupes -s %{buildroot}%{_javadocdir}

# demo
install -dm 0755 %{buildroot}%{_datadir}/%{base_name}/src
cp -pr xml %{buildroot}%{_datadir}/%{base_name}
cp -pr src/example %{buildroot}%{_datadir}/%{base_name}/src
%fdupes -s %{buildroot}%{_datadir}/%{base_name}

%files -f .mfiles
%license LICENSE
%doc README.md

%files demo
%{_datadir}/%{base_name}

%files javadoc
%license LICENSE
%{_javadocdir}/%{base_name}

%else

%files
%{_javadir}/%{base_name}.jar

%endif

%changelog
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Feb 15 2024 Fridrich Strba <fstrba@suse.com>
- The license is actually Plexus
* Thu Nov  2 2023 Anton Shvetz <shvetz.anton@gmail.com>
- JPMS: Add the Automatic-Module-Name attribute to the manifest.
* Thu Aug 24 2023 Fridrich Strba <fstrba@suse.com>
- Make a separate flavour for a minimal dom4j-bootstrap package
  used to build jaxen and full dom4j
- Added patch:
  * 0001-no-jaxen-dom4.patch
  * for the bootstrap package, patch out the code that requires
    jaxen with dom4j support to build
* Thu Aug 24 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 2.1.4
  * Improvements and potentially breaking changes
    + Added new factory method
    org.dom4j.io.SAXReader.createDefault(). It has more secure
    defaults than new SAXReader(), which uses system
    XMLReaderFactory.createXMLReader() or
    SAXParserFactory.newInstance().newSAXParser().
    + If you use some optional dependency of dom4j (for example
    Jaxen, xsdlib etc.), you need to specify an explicit
    dependency on it in your project. They are no longer marked as
    a mandatory transitive dependency by dom4j.
    + Following SAX parser features are disabled by default in
    DocumentHelper.parse() for security reasons (they were enabled
    in previous versions):
    ° http://xml.org/sax/properties/external-general-entities
    ° http://xml.org/sax/properties/external-parameter-entities
  * Other changes:
    + updated pull-parser version
    + Reuse the writeAttribute method in writeAttributes
    + support build on OS with non-UTF8 as default charset
    + Gradle: add an automatic module name
    + Use Correct License Name "Plexus"
    + Possible vulnerability of DocumentHelper.parseText() to XML
    injection
    + CVS directories left in the source tree
    + XMLWriter does not escape supplementary unicode characters
    correctly
    + writer.writeOpen(x) doesn't write namespaces
    + concurrency problem with QNameCache
    + all dependencies are optional
    + SAXReader: hardcoded namespace features
    + validate QNames
    + StringIndexOutOfBoundsException in
    XMLWriter.writeElementContent()
    + TreeNode has grown some generics
    + QName serialization fix
    + DocumentException initialize with nested exception
    + Accidentally occurring error in a multi-threaded test
    + compatibility with W3C DOM Level 3
    + use Java generics
- Removed patches:
  * dom4j-1.6.1-bug1618750.patch
  * dom4j-CVE-2018-1000632.patch
  * dom4j-CVE-2020-10683.patch
  * dom4j-enable-stax-datatypes.patch
  * dom4j-javadoc.patch
  * dom4j-sourcetarget.patch
    + not needed with this version
* Mon Jul 24 2023 Fridrich Strba <fstrba@suse.com>
- Do not depend on jtidy, since it is not used during build
* Wed Mar 30 2022 Fridrich Strba <fstrba@suse.com>
- Build against the standalone JavaEE modules unconditionally
* Mon Mar 28 2022 Fridrich Strba <fstrba@suse.com>
- Add alias to the new artifact coordinates org.dom4j:dom4j
- Simplify the spec file a bit
* Thu Mar 17 2022 Fridrich Strba <fstrba@suse.com>
- Add jaxb-api dependency for relevant distribution versions so that
  we can build with JDKs that do not include the JavaEE modules
* Fri Apr 17 2020 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Security fix: [bsc#1169760, CVE-2020-10683]
  * External Entity vulnerability in default SAX parser
  * Add dom4j-CVE-2020-10683.patch
* Fri Jan 25 2019 Cédric Bosdonnat <cbosdonnat@suse.com>
- Build STAXEventReader, STAXEventWriter and the data types.
  [bsc#1123158]
  * Added patch dom4j-enable-stax-datatypes.patch
* Tue Sep 18 2018 pmonrealgonzalez@suse.com
- Security fix: [bsc#1105443, CVE-2018-1000632]
  * Version prior to version 2.1.1 contains a CWE-91: XML
    Injectionvulnerability in Class: Element. Methods: addElement,
    addAttribute that canresult in an attacker tampering with XML
    documents through.
  * Added dom4j-CVE-2018-1000632.patch
* Tue Jul 10 2018 fstrba@suse.com
- Added patch:
  * dom4j-javadoc.patch
    + Don't load urls while building javadoc in environment without
    connectivity
* Wed May 16 2018 fstrba@suse.com
- Modified patch:
  * dom4j-sourcetarget.patch
    + Build with source and target 8 to prepare for a possible
    removal of 1.6 compatibility
* Fri Sep  8 2017 fstrba@suse.com
- Added patch:
  * dom4j-sourcetarget.patch
    + Use java source and target level 1.6 in order to allow
    building with jdk9
* Fri May 19 2017 mpluskal@suse.com
- Update dependencies
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Tue Jul  8 2014 tchvatal@suse.com
- Do not depend on ant-trax and run spec-cleaner.
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Wed Aug 28 2013 mvyskocil@suse.com
- use add_maven_depmap from javapackages-tools
- drop repolib part (never built)
- drop pointless jarjar
- unversioned javadoc
* Fri Mar 23 2012 cfarrell@suse.com
- license update: Apache-1.1
  SPDX
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Wed May 20 2009 mvyskocil@suse.cz
- 'fixed bnc#501764: removed clover.license from source tarball'
* Mon May 18 2009 mvyskocil@suse.cz
- Removed documentation of ConcurrentReaderHashMap (bnc#504663)
  * dom4j-1.6.1/docs/clover/org/dom4j/tree/ConcurrentReaderHashMap.html
  * dom4j-1.6.1/docs/xref/org/dom4j/tree/ConcurrentReaderHashMap.html
* Thu May 14 2009 mvyskocil@suse.cz
- Initial SUSE packaging:
  * spec script and jarjar build support was taken from jpackage.org 5.0
  * Source of dom4j and build.xml comes from Debian unstable, as there don't need
    proprietary msv from sun (bnc#430592)
